#include <FL/Fl.H>

#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Button.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Shared_Image.H>


class ImageBox : public Fl_Box
{
typedef Fl_Box Inherited;
public:
	ImageBox(int x_, int y_, int w_, int h_, const char *l_ = 0) :
		Inherited( x_, y_, w_, h_, l_ ), _bilinear( false ) {}
	void draw()
	{
		Fl_Image::scaling_algorithm( _bilinear ? FL_RGB_SCALING_BILINEAR : FL_RGB_SCALING_NEAREST );
		image()->scale( w(), h(), true, true );
		Inherited::draw();
	}
	void bilinear(bool bilinear_) { _bilinear = bilinear_; }
private:
	bool _bilinear;
};

int main( int argc_, char *argv_[] )
{
	const char *name = "../documentation/src/Fl_File_Chooser.jpg";

	fl_register_images();

	if ( argc_ > 1 )
		name = argv_[1];

	Fl_Shared_Image *image = Fl_Shared_Image::get(name);
	if ( !image )
		return 0;

	Fl_Image *rgb = image;
	if ( image->d() == 1 )
		rgb = new Fl_RGB_Image( (Fl_Pixmap *)image );
	int W = 800;
	int H = 600;
	Fl_Double_Window win( 0, 0, W, H );

	ImageBox b1( 0, 0, W/2, H, "nearest" );
	ImageBox b2( W/2, 0, W/2, H, "bilinear" );
	b2.bilinear( true );

	b1.image( rgb );
	b2.image( rgb );

	win.end();
	win.resizable(win);
	win.show();
	win.copy_label( name );

	return Fl::run();
}
